<?php

namespace Botble\TifrFacultyRecruitmentApplication\Http\Controllers;

use Botble\ACL\Models\Role;
use Botble\Base\Http\Actions\DeleteResourceAction;
use Botble\TifrFacultyRecruitmentApplication\Http\Requests\TifrFacultyRecruitmentApplicationRequest;
use Botble\TifrFacultyRecruitmentApplication\Models\TifrFacultyRecruitmentApplication;
use Botble\Base\Http\Controllers\BaseController;
use Botble\TifrFacultyRecruitmentApplication\Tables\TifrFacultyRecruitmentApplicationTable;
use Botble\TifrFacultyRecruitmentApplication\Forms\TifrFacultyRecruitmentApplicationForm;
use Theme\Tifr\Models\TifrFacultyRegistration;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

// class TifrFacultyRecruitmentApplicationController extends BaseController
class TifrFacultyRegistrationApplicationController extends BaseController
{
    public function __construct()
    {
        $this
            ->breadcrumb()
            ->add(trans(trans('plugins/tifrfacultyrecruitmentapplication::tifrfacultyrecruitmentapplication.name')), route('tifrfacultyrecruitmentapplication.index'));
    }

    public function getFacultyApplicationsList()
    {
        return view('tifrfacultyrecruitmentapplication::tifrfacultyrecruitmentapplication.tifr_faculty_registration_application_list');
    }

    public function getFacultyApplicationsListData(Request $request)
    {
        // Pagination and Search parameters
        $start = $request->input('start', 0);
        $length = $request->input('length', 10);
        $searchQuery = $request->input('searchQuery', '');
        $evaluationStatus = $request->input('evaluationStatus', '');

        $userRole = auth()->user()->roles()->first()->name;
        $userId = auth()->id();

        // Base SQL query for faculty registrations
        $sql = "
        SELECT 
            tifr_faculty_registrations.id,
            CONCAT(tifr_faculty_registrations.first_name, ' ', IFNULL(tifr_faculty_registrations.middle_name, ''), ' ', tifr_faculty_registrations.last_name) AS full_name,
            tifr_faculty_registrations.gender,
            tifr_faculty_registrations.email,
            tifr_faculty_registrations.phone,
            tifr_faculty_registration_evaluations.grade,
            tifr_faculty_registration_evaluations.recommendation,
            tifr_faculty_registration_evaluations.comments,
            tifr_faculty_registration_evaluations.evaluator_id,
            tifr_faculty_registration_evaluations.is_complete,
            tifr_faculty_registration_evaluation_statuses.final_status,
            tifr_faculty_registration_evaluation_statuses.final_status_comment,
            CASE 
        WHEN EXISTS (
            SELECT 1
            FROM tifr_faculty_registration_evaluations
            WHERE faculty_recruitment_application_id = tifr_faculty_registrations.id
            AND evaluator_id = $userId
            AND (grade IS NOT NULL OR recommendation IS NOT NULL OR comments IS NOT NULL)
        ) THEN 'Done'
        ELSE 'Pending'
      END AS evaluation_status,
            roles.name AS evaluator_role,
            CONCAT(users.first_name, ' ', users.last_name) AS evaluator_name,
            tifr_faculty_registrations.created_at
        FROM 
            tifr_faculty_registrations
        LEFT JOIN tifr_faculty_registration_evaluation_statuses 
            ON tifr_faculty_registrations.id = tifr_faculty_registration_evaluation_statuses.faculty_recruitment_application_id
        LEFT JOIN tifr_faculty_logins 
            ON tifr_faculty_logins.email = tifr_faculty_registrations.email
        
            LEFT JOIN (
            SELECT 
                e1.faculty_recruitment_application_id, 
                e1.grade, 
                e1.recommendation, 
                e1.comments, 
                e1.evaluator_id,
                e1.evaluation_date,
                e1.is_complete
            FROM tifr_faculty_registration_evaluations e1
            INNER JOIN (
                SELECT faculty_recruitment_application_id, MAX(evaluation_date) as max_date
                FROM tifr_faculty_registration_evaluations
                WHERE evaluator_id = $userId  -- Add this condition to filter by current user
                GROUP BY faculty_recruitment_application_id
            ) e2 ON e1.faculty_recruitment_application_id = e2.faculty_recruitment_application_id 
            AND e1.evaluation_date = e2.max_date
            WHERE e1.evaluator_id = $userId  -- Add this condition to ensure we only get current user's evaluations
        ) AS tifr_faculty_registration_evaluations 
        ON tifr_faculty_registrations.id = tifr_faculty_registration_evaluations.faculty_recruitment_application_id



        LEFT JOIN role_users 
            ON role_users.user_id = tifr_faculty_registration_evaluations.evaluator_id
        LEFT JOIN roles 
            ON roles.id = role_users.role_id
        LEFT JOIN users 
            ON users.id = tifr_faculty_registration_evaluations.evaluator_id
        WHERE
            tifr_faculty_logins.email_verified_at IS NOT NULL
     ";

        // Apply search filter if search query exists
        if ($searchQuery) {
            $sql .= "
        AND (tifr_faculty_registrations.first_name LIKE '%$searchQuery%' 
        OR tifr_faculty_registrations.last_name LIKE '%$searchQuery%' 
        OR tifr_faculty_registrations.email LIKE '%$searchQuery%')
       ";
        }

        // Role-based filter logic
        if ($userRole == 'Admin') {
            // Admin sees all applications, including evaluations for all
            $sql .= "";
        } elseif ($userRole == 'Committee Member' || $userRole == 'Chairperson') {
            // Committee members and Chairpersons see evaluations for their assigned applications
            $sql .= "
        AND (tifr_faculty_registration_evaluations.recommendation IS NULL
        OR tifr_faculty_registration_evaluations.recommendation IS NOT NULL
        OR tifr_faculty_registration_evaluations.evaluator_id = $userId
        OR tifr_faculty_registration_evaluations.evaluator_id IS NULL)
        ";
        } else {
            // For any other roles (like guest, etc.), show no results
            $sql .= " AND 1 = 0";
        }

        // Apply evaluation status filter if selected
        if ($evaluationStatus) {
            $sql .= "
        AND CASE 
                WHEN EXISTS (
                    SELECT 1
                    FROM tifr_faculty_registration_evaluations
                    WHERE faculty_recruitment_application_id = tifr_faculty_registrations.id
                    " . ($userRole !== 'Admin' ? "AND evaluator_id = $userId" : "") . "
                ) THEN 'Done'
                ELSE 'Pending'
            END = '$evaluationStatus'
        ";
        }

        $sql .= " AND tifr_faculty_registrations.combined_application IS NOT NULL AND tifr_faculty_registrations.combined_application != '' ";

        // Add ordering and pagination
        $sql .= " ORDER BY tifr_faculty_registrations.id DESC";

        if ($length != -1) {
            $sql .= " LIMIT $length OFFSET $start";
        }

        // echo $sql;
        // die;

        // Execute the query and get the applications
        $applications = DB::select($sql);

        // Handle export logic
        if ($request->has('export') && $request->input('export') === 'true') {
            // Fetch the filtered records using the provided SQL query
            $facultyData = DB::table('tifr_faculty_registrations')
                ->leftJoin('tifr_faculty_registration_evaluation_statuses', 'tifr_faculty_registrations.id', '=', 'tifr_faculty_registration_evaluation_statuses.faculty_recruitment_application_id')
                ->leftJoin('tifr_faculty_registration_evaluations', 'tifr_faculty_registrations.id', '=', 'tifr_faculty_registration_evaluations.faculty_recruitment_application_id')
                ->leftJoin('role_users', 'role_users.user_id', '=', 'tifr_faculty_registration_evaluations.evaluator_id')
                ->leftJoin(
                    'roles',
                    'roles.id',
                    '=',
                    'role_users.role_id'
                )
                ->leftJoin(
                    'users',
                    'users.id',
                    '=',
                    'tifr_faculty_registration_evaluations.evaluator_id'
                )
                ->select(
                    'tifr_faculty_registrations.id',
                    DB::raw('CONCAT(tifr_faculty_registrations.first_name, " ", tifr_faculty_registrations.middle_name, " ", tifr_faculty_registrations.last_name) as candidate_full_name'),
                    'tifr_faculty_registrations.gender',
                    'tifr_faculty_registrations.email',
                    'tifr_faculty_registrations.phone',
                    'tifr_faculty_registration_evaluations.evaluator_role',
                    'tifr_faculty_registration_evaluations.grade',
                    'tifr_faculty_registration_evaluations.recommendation',
                    'tifr_faculty_registration_evaluations.comments',
                    'tifr_faculty_registration_evaluations.evaluation_date', // Add evaluation_date to the selection
                    'tifr_faculty_registration_evaluation_statuses.is_complete',
                    'tifr_faculty_registration_evaluation_statuses.status_date as is_complete_date', // Add evaluation_date to the selection
                    'roles.slug as role_slug',
                    DB::raw('CONCAT(users.first_name, " ", users.last_name) as evaluator_full_name'),
                    'tifr_faculty_registrations.created_at as faculty_created_at'
                )
                ->orderBy('tifr_faculty_registrations.id', 'desc')
                ->get();

            // Group data by the faculty ID to associate multiple evaluators with the same faculty
            $groupedData = $facultyData->groupBy('id');

            // Generate CSV filename with timestamp
            $filename = 'faculty_applications_export_' . date('Y-m-d_H-i-s') . '.csv';

            return response()->stream(
                function () use ($groupedData) {
                    $handle = fopen('php://output', 'w');

                    // CSV headers - Start with basic faculty details first
                    $headers = [
                        'ID',
                        'Candidate Full Name',
                        'Gender',
                        'Email',
                        'Phone',
                        'Marked as Completed',
                        'Marked as Completed On',
                    ];

                    // Loop through the first group (faculty) to determine the maximum number of evaluators and add dynamic headers
                    $maxEvaluators = 0;
                    foreach ($groupedData as $facultyId => $facultyEvaluations) {
                        $maxEvaluators = max($maxEvaluators, $facultyEvaluations->count());
                    }

                    // Add evaluator columns dynamically based on the maximum number of evaluators
                    for ($i = 1; $i <= $maxEvaluators; $i++) {
                        $headers[] = "$i - Evaluator Role";
                        $headers[] = "$i - Evaluator Name";
                        $headers[] = "$i - Grade";
                        $headers[] = "$i - Recommendation";
                        $headers[] = "$i - Comments";
                        $headers[] = "$i - Evaluation Date";  // Add Evaluation Date for each evaluator
                    }

                    // Write the header to the CSV file
                    fputcsv($handle, $headers);

                    // Write data rows
                    foreach ($groupedData as $facultyId => $facultyEvaluations) {
                        // Get the faculty basic information (first evaluator)
                        $faculty = $facultyEvaluations->first();

                        // Start the row with the basic faculty information
                        $row = [
                            $faculty->id,
                            $faculty->candidate_full_name,
                            $faculty->gender,
                            $faculty->email,
                            $faculty->phone,
                            !empty($faculty->is_complete) ? $faculty->is_complete : 'No',
                            !empty($faculty->is_complete) && $faculty->is_complete == 'Yes' ? $faculty->is_complete_date : '-',
                        ];

                        // Check if 'is_complete' is 'No', if so, replace evaluator data with hyphens
                        $isComplete = $faculty->is_complete === 'Yes';

                        // Add evaluator information dynamically (add as many evaluators as present)
                        foreach ($facultyEvaluations as $evaluation) {
                            if ($isComplete) {
                                $row[] = $evaluation->evaluator_role ?? '-';
                                $row[] = $evaluation->evaluator_full_name ?? '-';
                                $row[] = $evaluation->grade ?? '-';
                                $row[] = $evaluation->recommendation ?? '-';
                                $row[] = $evaluation->comments ?? '-';
                                $row[] = $evaluation->evaluation_date ? $evaluation->evaluation_date : '-';  // Add the Evaluation Date
                            } else {
                                // If not complete, insert hyphens
                                $row[] = '-';
                                $row[] = '-';
                                $row[] = '-';
                                $row[] = '-';
                                $row[] = '-';
                                $row[] = '-';
                            }
                        }

                        // If there are fewer evaluators, fill the rest of the evaluator columns with empty values or hyphens
                        for ($i = $facultyEvaluations->count(); $i < $maxEvaluators; $i++) {
                            $row[] = '-';
                            $row[] = '-';
                            $row[] = '-';
                            $row[] = '-';
                            $row[] = '-';
                            $row[] = '-';
                        }

                        // Write the row to the CSV file
                        fputcsv($handle, $row);
                    }

                    fclose($handle);
                },
                200,
                [
                    'Content-Type' => 'text/csv',
                    'Content-Disposition' => 'attachment; filename="' . $filename . '"',
                ]
            );
        }

        // Get the filtered records count
        $filteredRecords = count($applications);

        // Get the total number of records for pagination (this counts the joined query, not just the base table)
        $totalRecords = DB::select("
                        SELECT COUNT(*) as count
                        FROM 
                            tifr_faculty_registrations
                        LEFT JOIN tifr_faculty_registration_evaluation_statuses 
                            ON tifr_faculty_registrations.id = tifr_faculty_registration_evaluation_statuses.faculty_recruitment_application_id
                        LEFT JOIN tifr_faculty_logins 
                            ON tifr_faculty_logins.email = tifr_faculty_registrations.email
                        
                                            LEFT JOIN (
                        SELECT faculty_recruitment_application_id, 
                            grade, 
                            recommendation, 
                            comments, 
                            evaluator_id
                        FROM tifr_faculty_registration_evaluations
                        WHERE (faculty_recruitment_application_id, evaluation_date) IN (
                            SELECT faculty_recruitment_application_id, MAX(evaluation_date)
                            FROM tifr_faculty_registration_evaluations
                            GROUP BY faculty_recruitment_application_id
                        )
                    ) AS tifr_faculty_registration_evaluations 
                        ON tifr_faculty_registrations.id = tifr_faculty_registration_evaluations.faculty_recruitment_application_id

                        LEFT JOIN role_users 
                            ON role_users.user_id = tifr_faculty_registration_evaluations.evaluator_id
                        LEFT JOIN roles 
                            ON roles.id = role_users.role_id
                        LEFT JOIN users 
                            ON users.id = tifr_faculty_registration_evaluations.evaluator_id
                        WHERE
                            tifr_faculty_logins.email_verified_at IS NOT NULL
                    ");
        $totalRecords = $totalRecords[0]->count;

        // Dynamically create the "Actions" column HTML after fetching the data
        $applications = collect($applications)->map(function ($item) use ($userRole, $userId) {
            // Check if the evaluation details are available and if the logged-in user has evaluated the application
            $evaluationDetails = '-';

            // Admin can only see their own evaluations, but not others
            if ($userRole === 'Admin') {
                // Do not show evaluation details for other roles; only show when the Admin has evaluated this application
                if (!empty($item->final_status)) {
                    $item->evaluation_status = 'Done';
                    if ($item->final_status || $item->final_status_comment) {
                        $evaluationDetails = '';
                        if ($item->final_status) {

                            $evaluationDetails .= 'Final Status: ' . $item->final_status . '<br>';
                        }
                        if ($item->final_status_comment) {
                            $evaluationDetails .= 'Comment: <i class="fa-solid fa-circle-info" style="cursor: pointer; color: #007bff; font-weight: bold; font-size: 16px;" title="' . $item->final_status_comment . '"></i>';
                        }
                    }
                } else {
                    $item->evaluation_status = 'Pending';
                }
            } else {
                // For Committee Members or Chairpersons, show details only if they evaluated the application
                if ($item->evaluator_id === $userId) {
                    if ($item->grade || $item->recommendation || $item->comments) {
                        $evaluationDetails = '';
                        // Add grade, recommendation, and comments if they exist
                        if ($item->grade) {
                            $evaluationDetails .= 'Grade: ' . $item->grade . '<br>';
                        }
                        if ($item->recommendation) {
                            $evaluationDetails .= 'Recommendation: ' . $item->recommendation . '<br>';
                        }
                        if ($item->comments) {
                            $evaluationDetails .= 'Comment: <i class="fa-solid fa-circle-info" style="cursor: pointer; color: #007bff; font-weight: bold; font-size: 16px;" title="' . $item->comments . '"></i>';
                        }
                    }
                }
            }

            // Set the evaluation details for each application
            $item->evaluation_details = $evaluationDetails;


            $isCompleteByChairperson = DB::table('tifr_faculty_registration_evaluations')
                ->where('faculty_recruitment_application_id', $item->id)
                ->where('evaluator_role', 'Chairperson') // Chairperson's ID
                ->value('is_complete'); // Fetch the is_complete value directly

            // Conditionally render Evaluate button or View Evaluation button based on whether the application has been evaluated by the user
            $evaluateButton = '<a href="' . route('tifrfacultyrecruitmentapplication.edit', ['id' => $item->id]) . '" class="btn btn-sm btn-primary view-my-evaluation-btn">' .
                ($item->evaluation_status !== 'Done' ? 'Evaluate' : 'View Evaluation') .
                '</a>';

            // Add "View All Evaluation Details" button if is_complete is "Yes"
            $evaluationDetailsButton = '';
            if ($isCompleteByChairperson === 'Yes') {
                $evaluationDetailsButton = '<a href="' . route('tifrfacultyrecruitmentapplication.committee.recommendations', ['id' => $item->id]) . '" class="btn btn-sm btn-primary view-grade-btn">View Grade</a>';
            }

            // Combine the "Evaluate" and "View All Evaluation Details" buttons in the 'actions' column
            $item->actions = trim($evaluateButton . ($evaluateButton && $evaluationDetailsButton ? '<br><br>' : '') . $evaluationDetailsButton);

            return $item;
        });

        return response()->json([
            'draw' => $request->input('draw'),
            'recordsTotal' => $totalRecords,
            'recordsFiltered' => $filteredRecords,
            'data' => $applications
        ]);
    }


    // public function index(TifrFacultyRecruitmentApplicationTable $table)
    // {
    //     $this->pageTitle(trans('plugins/tifrfacultyrecruitmentapplication::tifrfacultyrecruitmentapplication.name'));

    //     return $table->renderTable();
    // }

    public function index()
    {
        $this->pageTitle(trans('plugins/tifrfacultyrecruitmentapplication::tifrfacultyrecruitmentapplication.name'));

        return view('tifrfacultyrecruitmentapplication::tifrfacultyrecruitmentapplication.tifr_faculty_registration_application_list');
    }

    public function exportFacultyApplication()
    {
        $facultyData = DB::table('tifr_faculty_registrations')
            ->leftJoin('tifr_faculty_registration_evaluation_statuses', 'tifr_faculty_registrations.id', '=', 'tifr_faculty_registration_evaluation_statuses.faculty_recruitment_application_id')
            ->leftJoin('tifr_faculty_registration_evaluations', 'tifr_faculty_registrations.id', '=', 'tifr_faculty_registration_evaluations.faculty_recruitment_application_id')
            ->leftJoin('role_users', 'role_users.user_id', '=', 'tifr_faculty_registration_evaluations.evaluator_id')
            ->leftJoin('roles', 'roles.id', '=', 'role_users.role_id')
            ->leftJoin('users', 'users.id', '=', 'tifr_faculty_registration_evaluations.evaluator_id')
            ->select(
                'tifr_faculty_registrations.first_name',
                'tifr_faculty_registrations.middle_name',
                'tifr_faculty_registrations.last_name',
                'tifr_faculty_registrations.gender',
                'tifr_faculty_registrations.email',
                'tifr_faculty_registrations.phone',
                'tifr_faculty_registration_evaluations.evaluator_role',
                'tifr_faculty_registration_evaluations.grade',
                'tifr_faculty_registration_evaluations.recommendation',
                'tifr_faculty_registration_evaluations.comments',
                'tifr_faculty_registration_evaluations.is_complete',
                'roles.slug as role_slug',
                'users.first_name as evaluator_first_name',
                'users.last_name as evaluator_last_name'
            )
            ->orderBy('tifr_faculty_registrations.first_name', 'asc')
            ->get();

        $exportData = $facultyData->map(function ($item) {

            $evaluatorFullName = $item->evaluator_first_name . ' ' . $item->evaluator_last_name;

            return [
                'full_name' => $item->first_name . ' ' . $item->middle_name . ' ' . $item->last_name,
                'gender' => $item->gender,
                'email' => $item->email,
                'phone' => $item->phone,
                'is_complete' => !empty($item->is_complete) ? $item->is_complete : 'No',
                'evaluator_role' => !empty($item->evaluator_role) ? $item->evaluator_role : '-',
                'evaluator_name' => !empty($evaluatorFullName) ? $evaluatorFullName : '-',
                'grade' => !empty($item->grade) ? $item->grade : '-',
                'recommendation' => !empty($item->recommendation) ? $item->recommendation : '-',
                'comment' => !empty($item->comments) ? $item->comments : '-',
            ];
        });

        $csv = 'Full Name, Gender, Email, Phone, Mark Completed, Evaluator Role, Evaluator Name, Grade, Recommendation, Comment' . "\n";

        foreach ($exportData as $row) {
            $csv .= implode(',', [
                $row['full_name'],
                $row['gender'],
                $row['email'],
                $row['phone'],
                $row['is_complete'],
                $row['evaluator_role'],
                $row['evaluator_name'],
                $row['grade'],
                $row['recommendation'],
                $row['comment'],
            ]) . "\n";
        }

        return response($csv)
            ->header('Content-Type', 'text/csv')
            ->header('Content-Disposition', 'attachment; filename="faculty_evaluations.csv"');
    }

    public function getFilteredFacultyData(Request $request)
    {
        // Get the evaluation status from the request
        $evaluationStatus = $request->input('evaluation_status');

        // Query to fetch filtered data
        $facultyDataQuery = DB::table('tifr_faculty_registrations')
            ->leftJoin('tifr_faculty_registration_evaluations', 'tifr_faculty_registrations.id', '=', 'tifr_faculty_registration_evaluations.faculty_recruitment_application_id')
            ->leftJoin('role_users', 'role_users.user_id', '=', 'tifr_faculty_registration_evaluations.evaluator_id')
            ->leftJoin('roles', 'roles.id', '=', 'role_users.role_id')
            ->leftJoin('users', 'users.id', '=', 'tifr_faculty_registration_evaluations.evaluator_id')
            ->select(
                'tifr_faculty_registrations.id',
                DB::raw('CONCAT(tifr_faculty_registrations.first_name, " ", IFNULL(tifr_faculty_registrations.middle_name, ""), " ", tifr_faculty_registrations.last_name) AS full_name'),
                'tifr_faculty_registrations.gender',
                'tifr_faculty_registrations.email',
                'tifr_faculty_registrations.phone',
                'tifr_faculty_registration_evaluations.evaluator_role',
                'tifr_faculty_registration_evaluations.grade',
                'tifr_faculty_registration_evaluations.recommendation',
                'tifr_faculty_registration_evaluations.comments',
                'roles.slug as role_slug',
                'users.first_name as evaluator_first_name',
                'users.last_name as evaluator_last_name',
                DB::raw('
            CASE 
                WHEN EXISTS (
                    SELECT 1
                    FROM tifr_faculty_registration_evaluations
                    WHERE faculty_recruitment_application_id = tifr_faculty_registrations.id
                    AND evaluator_id = tifr_faculty_registration_evaluations.evaluator_id
                ) THEN "Done"
                ELSE "Pending"
            END AS evaluation_status
            '),
                // Add the evaluation details column using a raw SQL expression
                DB::raw('COALESCE(CONCAT(
                "Grade - ", tifr_faculty_registration_evaluations.grade, "<br>",
                "Recommendation - ", tifr_faculty_registration_evaluations.recommendation, "<br>",
                "Comment - ", 
                IFNULL(
                    CONCAT(
                        "<i class=\"fa-solid fa-circle-info\" style=\"cursor: pointer; color: #007bff; font-weight: bold; font-size: 16px;\" title=\"", tifr_faculty_registration_evaluations.comments, "\"></i>"),
                    "-")
            ), "-") AS evaluation_details')
            );

        // Filter based on the evaluation status if provided
        if ($evaluationStatus) {
            $facultyDataQuery->whereRaw('
            CASE 
                WHEN EXISTS (
                    SELECT 1
                    FROM tifr_faculty_registration_evaluations
                    WHERE faculty_recruitment_application_id = tifr_faculty_registrations.id
                    AND evaluator_id = tifr_faculty_registration_evaluations.evaluator_id
                ) THEN "Done"
                ELSE "Pending"
            END = ?', [$evaluationStatus]);
        }

        // Execute the query and get the results
        $facultyData = $facultyDataQuery->get();

        // Count total records (this could be the same as filtered if no other filtering happens)
        $totalRecords = DB::table('tifr_faculty_registrations')->count();
        $filteredRecords = $facultyData->count(); // This is after filtering

        // Return the filtered data as JSON (ensure it's in a DataTable-friendly format)
        return response()->json([
            'draw' => $request->input('draw', 1),  // To support DataTable pagination
            'recordsTotal' => $totalRecords,
            'recordsFiltered' => $filteredRecords,
            'data' => $facultyData->map(function ($row) {

                // IdColumn::make(),
                // NameColumn::make('full_name')->label('Full Name')->route('tifrfacultyrecruitmentapplication.edit'),
                // Column::make('gender')->label('Gender'),
                // Column::make('email')->label('Email'),
                // Column::make('phone')->label('Phone'),
                // Column::make('evaluation_status')->label('Evaluation'),
                // Column::make('evaluation_details')->label('Evaluation Details'),
                // CreatedAtColumn::make(),

                return [
                    'id' => $row->id,
                    'full_name' => $row->full_name,
                    'gender' => $row->gender,
                    'email' => $row->email,
                    'phone' => $row->phone,
                    'evaluation_status' => $row->evaluation_status,
                    'evaluation_details' => $row->evaluation_details,  // Now, this is correctly available
                    'row_actions' => '<a href="/edit/' . $row->id . '" class="btn btn-sm btn-primary">Edit</a>'

                    // 'evaluator_name' => $row->evaluator_first_name . ' ' . $row->evaluator_last_name,
                    // 'evaluator_role' => $row->evaluator_role,
                    // 'grade' => $row->grade,
                    // 'recommendation' => $row->recommendation,
                    // 'comments' => $row->comments,
                ];
            }),
        ]);
    }

    public function store(TifrFacultyRecruitmentApplicationRequest $request)
    {
        $form = TifrFacultyRecruitmentApplicationForm::create()->setRequest($request);

        $form->save();

        return $this
            ->httpResponse()
            ->setPreviousUrl(route('tifrfacultyrecruitmentapplication.index'))
            ->setNextUrl(route('tifrfacultyrecruitmentapplication.edit', $form->getModel()->getKey()))
            ->setMessage(trans('core/base::notices.create_success_message'));
    }

    public function edit($id)
    {

        $facultyRecruitment = TifrFacultyRegistration::findOrFail($id);

        $fullName = trim(
            $facultyRecruitment->first_name . ' ' .
                $facultyRecruitment->middle_name . ' ' .
                $facultyRecruitment->last_name
        );

        // remove extra spaces if there is no middle name
        $fullName = preg_replace('/\s+/', ' ', $fullName);

        $this->pageTitle(trans('core/base::forms.edit_item', ['name' => $fullName]));

        $logged_in_user_id = auth()->id();
        $userRole = auth()->user()->roles()->first()->name;
        // $userRole = Role::first()->name;

        $evaluations = TifrFacultyRecruitmentApplication::where('faculty_recruitment_application_id', $id)
            ->where('evaluator_id', $logged_in_user_id)
            ->first();

        $can_edit_grade_recom_comment = ($userRole === 'Committee Member' || $userRole === 'Chairperson') && !$evaluations;

        $evaluationStatus = $this->checkEvaluationStatus($id);

        // echo '<pre>';
        // print_r($facultyRecruitment);
        // print_r($evaluations);
        // die;

        $final_status = DB::table('tifr_faculty_registration_evaluation_statuses')
            ->where('faculty_recruitment_application_id', $id)
            ->first();

        $mark_as_complete_status = DB::table('tifr_faculty_registration_evaluations')
            ->where('faculty_recruitment_application_id', $id)
            ->where('evaluator_role', 'Chairperson')
            ->first();

        // Retrieve the salutation from the `tifr_form_salutations` table
        $salutation = DB::table('tifr_form_salutations')
            ->where('id', $facultyRecruitment->salutation)
            ->value('salutation_name');

        // Retrieve the country from the `tifr_form_countries` table
        $country = DB::table('tifr_form_countries')
            ->where('id', $facultyRecruitment->country)
            ->value('country_name');

        return view('tifrfacultyrecruitmentapplication::tifrfacultyrecruitmentapplication.tifr_faculty_registration_application_form', compact(
            'facultyRecruitment',
            'evaluations',
            'can_edit_grade_recom_comment',
            'evaluationStatus',
            'final_status',
            'mark_as_complete_status',
            'salutation',
            'country'
        ));
    }

    public function checkEvaluationStatus($applicationId)
    {
        $committeeCount = DB::table('role_users as ru')
            ->join('roles as r', 'r.id', '=', 'ru.role_id')
            ->where('r.name', 'Committee Member') // Use 'committee-member' role
            ->distinct()
            ->count(); // Count the distinct committee members across all applications

        // var_dump($committeeCount);
        // die;

        // Get the number of evaluations already submitted by committee members for this specific application
        $completedEvaluationsbycommittee = DB::table('tifr_faculty_registration_evaluations')
            ->where('faculty_recruitment_application_id', $applicationId)
            ->where('evaluator_role', 'Committee Member') // Only for committee members
            ->distinct('evaluator_id') // Count distinct evaluators
            ->count(); // Count the number of completed evaluations

        // var_dump($completedEvaluationsbycommittee);
        // die;

        // If the number of committee members matches the number of completed evaluations, allow completion
        // if ($committeeCount == $completedEvaluationsbycommittee) {
        //     return 'allow_complete';  // All evaluations are done, Chairman can mark as complete
        // } else {
        //     return 'wait_for_evaluations';  // Not all evaluations are done, Chairman must wait
        // }


        // Check if all evaluations are complete
        $status = ($committeeCount == $completedEvaluationsbycommittee) ? 'allow_complete' : 'wait_for_evaluations';

        // Return all the relevant data: the status, completed evaluations, and committee count
        return [
            'status' => $status,
            'committee_count' => $committeeCount,
            'completed_evaluations' => $completedEvaluationsbycommittee,
        ];
    }


    public function showCommitteeRecommendations($id)
    {
        // Fetch the status of the application to ensure it's complete
        $status = DB::table('tifr_faculty_registration_evaluations')
            ->where('faculty_recruitment_application_id', $id)
            ->where('evaluator_role', 'Chairperson')
            ->first();

        if (!$status || $status->is_complete !== 'Yes') {
            // If the application is not marked as complete, you can redirect or show an error message
            return redirect()->route('tifrfacultyrecruitmentapplication.index')->with('error', 'The application has not been marked as complete.');
        }

        // Fetch grades and recommendations from evaluators
        $gradesAndRecommendations = DB::table('tifr_faculty_registration_evaluations')
            ->join('users', 'tifr_faculty_registration_evaluations.evaluator_id', '=', 'users.id')
            ->join('role_users', 'role_users.user_id', '=', 'users.id') // Join with role_users to get the role
            ->join('roles', 'roles.id', '=', 'role_users.role_id') // Join with roles to get the role name
            ->where('tifr_faculty_registration_evaluations.faculty_recruitment_application_id', $id)
            ->select(
                'tifr_faculty_registration_evaluations.grade',
                'tifr_faculty_registration_evaluations.recommendation',
                'tifr_faculty_registration_evaluations.comments',
                DB::raw("CONCAT(users.first_name, ' ', users.last_name) as evaluator_full_name"),
                'roles.name as evaluator_role' // Fetch the role name
            )
            ->get();

        // Fetch the final approval status from the evaluation statuses table
        $finalApprovalStatus = DB::table('tifr_faculty_registration_evaluation_statuses')
            ->where('faculty_recruitment_application_id', $id)
            ->first();

        // Return the view with the grades and recommendations, and the final approver details
        return view('tifrfacultyrecruitmentapplication::tifrfacultyrecruitmentapplication.tifr_committee_evaluations', [
            'gradesAndRecommendations' => $gradesAndRecommendations,
            'finalApprovalStatus' => $finalApprovalStatus
        ]);
    }

    public function update(TifrFacultyRecruitmentApplication $tifrFacultyRecruitmentApplication, TifrFacultyRecruitmentApplicationRequest $request)
    {
        TifrFacultyRecruitmentApplicationForm::createFromModel($tifrFacultyRecruitmentApplication)
            ->setRequest($request)
            ->save();

        return $this
            ->httpResponse()
            ->setPreviousUrl(route('tifrfacultyrecruitmentapplication.index'))
            ->setMessage(trans('core/base::notices.update_success_message'));
    }

    public function destroy(TifrFacultyRecruitmentApplication $tifrFacultyRecruitmentApplication)
    {
        return DeleteResourceAction::make($tifrFacultyRecruitmentApplication);
    }

    public function evaluationStatusUpdate(Request $request, $facultyRecruitmentId)
    {
        TifrFacultyRegistration::findOrFail($facultyRecruitmentId);

        $data = $request->all();

        // echo '<pre>';
        // print_r($data);
        // die;

        $logged_in_user_id = auth()->id();
        // $logged_in_user_role = Role::first()->name;
        $logged_in_user_role = auth()->user()->roles()->first()->name;

        $evaluationStatus = TifrFacultyRecruitmentApplication::where('faculty_recruitment_application_id', $facultyRecruitmentId)
            ->where('evaluator_id', $logged_in_user_id)
            ->first();

        // Step 2: Check if "mark_complete" is set to 'Yes' in the request
        $isComplete = ($request->has('mark_complete') && $request->input('mark_complete') == 'Yes') ? 'Yes' : 'No';

        if ($evaluationStatus) {
        } else {

            if ($logged_in_user_role == 'Committee Member' || $logged_in_user_role == 'Chairperson') {
                // Create a new evaluation status record if not already created
                TifrFacultyRecruitmentApplication::create([
                    'faculty_recruitment_application_id' => $facultyRecruitmentId,
                    'evaluator_id' => $logged_in_user_id,
                    'evaluator_role' => $logged_in_user_role,
                    'grade' => isset($data['grade']) ? $data['grade'] : null,
                    'recommendation' => isset($data['recommendation']) ? $data['recommendation'] : null,
                    'comments' => isset($data['comments']) ? $data['comments'] : null,
                    'is_complete' => $isComplete,
                    'evaluation_date' => now(),
                    'updated_at' => now(),
                ]);
            }
        }



        $final_status = null;
        $final_status_comment = null;
        if (isset($data['final_status'])) {
            $final_status = $data['final_status'];
            $final_status_comment = $data['final_status_comment'];
        }

        if ($logged_in_user_role == 'Admin') {
            // Step 3: Insert or Update Faculty Application Status (tifr_faculty_registration_evaluation_statuses)
            $this->insertOrUpdateApplicationStatus($facultyRecruitmentId, $logged_in_user_id, $logged_in_user_role, $final_status, $final_status_comment);
        }

        // Step 4: Return Response
        return $this->httpResponse()
            ->setPreviousUrl(route('tifrfacultyrecruitmentapplication.index'))
            ->setMessage(trans('core/base::notices.update_success_message'));
    }

    private function insertOrUpdateApplicationStatus($facultyRecruitmentId, $logged_in_user_id, $logged_in_user_role, $final_status, $final_status_comment)
    {
        // Check if the status record already exists
        $existingStatus = DB::table('tifr_faculty_registration_evaluation_statuses')
            ->where('faculty_recruitment_application_id', $facultyRecruitmentId)
            ->where('final_approver_id', $logged_in_user_id)
            ->first();

        // Prepare data for insert or update
        $statusData = [
            'faculty_recruitment_application_id' => $facultyRecruitmentId,
            'final_approver_id' => $logged_in_user_id,
            'final_approver_role' => $logged_in_user_role,
            'final_status' => $final_status,
            'final_status_comment' => $final_status_comment,
            'status_date' => now(),
            'updated_at' => now(),
        ];

        if ($existingStatus) {
            // If the status record exists, update it
            DB::table('tifr_faculty_registration_evaluation_statuses')
                ->where('faculty_recruitment_application_id', $facultyRecruitmentId)
                ->update($statusData);
        } else {
            // If the status record doesn't exist, insert it
            $statusData['created_at'] = now();
            DB::table('tifr_faculty_registration_evaluation_statuses')->insert($statusData);
        }
    }
}
