<?php

namespace Botble\TifrFacultyRecruitmentApplication\Tables;

// use Botble\TifrFacultyRecruitmentApplication\Models\TifrFacultyRecruitmentApplication;
use Botble\Table\Abstracts\TableAbstract;
// use Botble\Table\Actions\DeleteAction;
use Botble\Table\Actions\EditAction;
// use Botble\Table\BulkActions\DeleteBulkAction;
// use Botble\Table\BulkChanges\CreatedAtBulkChange;
// use Botble\Table\BulkChanges\NameBulkChange;
// use Botble\Table\BulkChanges\StatusBulkChange;
use Botble\Table\Columns\CreatedAtColumn;
use Botble\Table\Columns\IdColumn;
use Botble\Table\Columns\NameColumn;
// use Botble\Table\Columns\StatusColumn;
use Botble\Table\Columns\Column;
// use Botble\Table\HeaderActions\CreateHeaderAction;
use Illuminate\Database\Eloquent\Builder;

class TifrFacultyRecruitmentApplicationTable extends TableAbstract
{
    public function setup(): void
    {
        $this
            // ->model(TifrFacultyRecruitmentApplication::class)
            // ->addHeaderAction(CreateHeaderAction::make()->route('tifrfacultyrecruitmentapplication.create'))
            ->addActions([
                EditAction::make()->route('tifrfacultyrecruitmentapplication.edit'),
                // DeleteAction::make()->route('tifrfacultyrecruitmentapplication.destroy'),
            ])
            ->addColumns([
                IdColumn::make(),
                // NameColumn::make()->route('tifrfacultyrecruitmentapplication.edit'),
                // StatusColumn::make(),
                NameColumn::make('full_name')->label('Full Name')->route('tifrfacultyrecruitmentapplication.edit'),
                Column::make('gender')->label('gender'),
                Column::make('email')->label('email'),
                Column::make('address')->label('address'),
                CreatedAtColumn::make(),
            ])
            // ->addBulkActions([
            //     DeleteBulkAction::make()->permission('tifrfacultyrecruitmentapplication.destroy'),
            // ])
            // ->addBulkChanges([
            //     NameBulkChange::make(),
            //     StatusBulkChange::make(),
            //     CreatedAtBulkChange::make(),
            // ])
            ->queryUsing(function (Builder $query) {
                // $query->select([
                //     'id',
                //     'name',
                //     'created_at',
                //     'status',
                // ]);
                // $logged_in_user_id = auth()->id();
                // $query->from('faculty_recruitments')
                //     ->join('tifr_faculty_application_evaluation', 'faculty_recruitments.id', '=', 'tifr_faculty_application_evaluation.faculty_recruitment_application_id')
                //     ->where('tifr_faculty_application_evaluation.evaluator_id', $logged_in_user_id) // Filter by evaluator ID
                //     ->select([
                //         'faculty_recruitments.id',
                //         \DB::raw('CONCAT(faculty_recruitments.first_name, " ", IFNULL(faculty_recruitments.middle_name, ""), " ", faculty_recruitments.last_name) AS full_name'),
                //         'faculty_recruitments.gender',
                //         'faculty_recruitments.email',
                //         'faculty_recruitments.address',
                //         'faculty_recruitments.created_at',
                //     ]);

                $logged_in_user_id = auth()->id();

                // Determine if the logged-in user is a "Committee Member" or "Chairperson"
                // We assume you have a way to get roles. For example, using a `roles` column or table.
                $userRole = auth()->user()->roles()->first()->name; // Assuming role is a property on the user model (change as necessary)

                // Filter by the evaluator_id (for committee members and chairperson)
                if ($userRole == 'Committee Member') {
                    $query->from('faculty_recruitments')
                        ->leftJoin('tifr_faculty_application_evaluation', 'faculty_recruitments.id', '=', 'tifr_faculty_application_evaluation.faculty_recruitment_application_id')
                        // ->where('tifr_faculty_application_evaluation.evaluator_id', $logged_in_user_id)  // Filter by the logged-in committee member

                        ->where(function ($query) use ($logged_in_user_id) {
                            // For Committee Members, we check if the recommendation is NULL (pending) or already filled
                            $query->whereNull('tifr_faculty_application_evaluation.recommendation')  // Pending evaluation (NULL recommendation)
                                ->orWhereNotNull('tifr_faculty_application_evaluation.recommendation') // Evaluated (not NULL)
                                // Add condition to ensure that the logged-in user is the evaluator or no evaluation exists (NULL evaluator_id)
                                ->orWhere(function ($subQuery) use ($logged_in_user_id) {
                                    $subQuery->where('tifr_faculty_application_evaluation.evaluator_id', $logged_in_user_id) // Evaluator is the logged-in user
                                        ->orWhereNull('tifr_faculty_application_evaluation.evaluator_id'); // Or no evaluation exists yet (NULL evaluator_id)
                                });
                        })
                        ->select([
                            'faculty_recruitments.id',
                            \DB::raw('CONCAT(faculty_recruitments.first_name, " ", IFNULL(faculty_recruitments.middle_name, ""), " ", faculty_recruitments.last_name) AS full_name'),
                            'faculty_recruitments.gender',
                            'faculty_recruitments.email',
                            'faculty_recruitments.address',
                            'faculty_recruitments.created_at',
                            'tifr_faculty_application_evaluation.recommendation'
                        ]);
                } elseif ($userRole == 'Chairperson') {
                    // For Chairperson, we need to check if all committee members have submitted their recommendations
                    $query->from('faculty_recruitments')
                        ->join('tifr_faculty_application_evaluation', 'faculty_recruitments.id', '=', 'tifr_faculty_application_evaluation.faculty_recruitment_application_id')
                        ->leftJoin('tifr_faculty_application_status', 'faculty_recruitments.id', '=', 'tifr_faculty_application_status.faculty_recruitment_application_id')
                        ->where(function ($query) {
                            // Check if 'is_complete' is either '1' or NULL
                            $query->where('tifr_faculty_application_status.is_complete', '1')
                                ->orWhereNull('tifr_faculty_application_status.is_complete');
                        })
                        ->whereNotNull('tifr_faculty_application_evaluation.evaluator_id') // Ensure evaluator_id is not null
                        ->whereIn('tifr_faculty_application_evaluation.recommendation', ['Yes', 'No']) // Ensure recommendation is either 'yes' or 'no'
                        ->whereExists(function ($query) {
                            // Subquery to ensure all committee members have submitted recommendations
                            $query->select(\DB::raw(1))
                                ->from('role_users')  // Ensure correct table name
                                ->join('roles', 'roles.id', '=', 'role_users.role_id')
                                ->where('roles.slug', 'LIKE', '%committee_member%')  // Only committee members
                                ->whereIn('role_users.user_id', function ($subQuery) {
                                    // Get evaluator_ids from the faculty recruitment application evaluation table
                                    $subQuery->select('evaluator_id')
                                        ->from('tifr_faculty_application_evaluation')
                                        ->whereColumn('faculty_recruitment_application_id', 'faculty_recruitments.id');
                                })
                                ->havingRaw('COUNT(DISTINCT role_users.user_id) = COUNT(DISTINCT tifr_faculty_application_evaluation.evaluator_id)');
                        })
                        ->select([
                            'faculty_recruitments.id',
                            \DB::raw('CONCAT(faculty_recruitments.first_name, " ", IFNULL(faculty_recruitments.middle_name, ""), " ", faculty_recruitments.last_name) AS full_name'),
                            'faculty_recruitments.gender',
                            'faculty_recruitments.email',
                            'faculty_recruitments.address',
                            'faculty_recruitments.created_at',
                        ]);
                } else {
                    // If the user is neither Committee Member nor Chairperson, you can return an empty result or restrict access.
                    // $query->whereRaw('1 = 0'); // This will return no records

                    $query->from('faculty_recruitments')
                        ->whereRaw('1 = 0'); // This ensures no records are returned by the query
                }
            });
    }
}
