<?php

namespace Botble\TifrTeamMaster\Providers;

use Botble\Base\Supports\ServiceProvider;
use Botble\Base\Traits\LoadAndPublishDataTrait;
use Botble\Base\Facades\DashboardMenu;
use Botble\TifrTeamMaster\Models\TifrTeamMaster;

class TifrTeamMasterServiceProvider extends ServiceProvider
{
    use LoadAndPublishDataTrait;

    public function boot(): void
    {
        $this
            ->setNamespace('plugins/tifrteammaster')
            ->loadHelpers()
            ->loadAndPublishConfigurations(['permissions'])
            ->loadAndPublishTranslations()
            ->loadRoutes()
            ->loadAndPublishViews()
            ->loadMigrations();

        // Register the views directory with the correct namespace
        $this->loadViewsFrom(
            platform_path('plugins/tifr-team-master/resources/views'),
            'tifrteammaster' // This defines the view namespace you're using
        );

        if (defined('LANGUAGE_ADVANCED_MODULE_SCREEN_NAME')) {
            \Botble\LanguageAdvanced\Supports\LanguageAdvancedManager::registerModule(TifrTeamMaster::class, [
                'name',
            ]);
        }

        DashboardMenu::default()->beforeRetrieving(function () {
            DashboardMenu::registerItem([
                'id' => 'cms-plugins-tifrteammaster',
                'priority' => 5,
                'parent_id' => null,
                'name' => 'plugins/tifrteammaster::tifrteammaster.name',
                'icon' => 'ti ti-box',
                'url' => route('tifrteammaster.index'),
                'permissions' => ['tifrteammaster.index'],
            ]);
        });
    }
}
