<?php

use Botble\Theme\Facades\Theme;
use Illuminate\Support\Facades\Route;
use Theme\Tifr\Http\Controllers\TifrController;
use Theme\Tifr\Http\Controllers\TifrFacultyRegistrationController;
use Theme\Tifr\Http\Controllers\TifrFacultyLoginController;

use Illuminate\Support\Facades\Mail;

Route::get('send-test-email', function () {
    $data = [
        'name' => 'John Doe',
        'email_verification_token_link' => 'John Doe',
        'site_copyright' => 'John Doe',
        'site_email' => 'John Doe'
    ];

    Mail::send('emails.registration_confirmation', $data, function ($message) {
        $message->to('john@gmail.com')
            ->subject('Test Email');
    });

    return 'Test email sent!';
});

// http://localhost/laravel_cms_7.4.5_tifr/public/send-test-email

// Custom routes
// You can delete this route group if you don't need to add your custom routes.
Route::group(['controller' => TifrController::class, 'middleware' => ['web', 'core']], function () {
    Route::group(apply_filters(BASE_FILTER_GROUP_PUBLIC_ROUTE, []), function () {

        // Add your custom route here
        // Ex: Route::get('hello', 'getHello');

        Route::get('search-result', 'getGlobalSearch')->name('global.search');
        Route::get('calendar/search', 'getCalendarSearch')->name('calendar.search');
        Route::get('news-events/search', 'getNewsSearch')->name('news.search');

        Route::get('faculty-detail/{id}', 'getFacultyDetail')->name('faculty.detail');

        Route::get('faculty-recruitment/faculty-registration', [TifrFacultyRegistrationController::class, 'faculty_registration'])->name('faculty-recruitment.faculty-registration');

        Route::post('faculty-recruitment/store', [TifrFacultyRegistrationController::class, 'store'])->name('faculty-recruitment.store');

        Route::post('faculty-recruitment/update', [TifrFacultyRegistrationController::class, 'update'])->name('faculty-recruitment.update');

        Route::get('faculty-recruitment/thankyou', [TifrFacultyRegistrationController::class, 'thankyou'])->name('faculty-recruitment.thankyou');

        Route::post('faculty-recruitment/validate-math-captcha-and-user-uniqueness', [TifrFacultyRegistrationController::class, 'validateMathCaptchaAndUserUniqueness'])->name('faculty-recruitment.validate-math-captcha-and-user-uniqueness');

        Route::get('faculty/login', [TifrFacultyLoginController::class, 'showFacultyLoginForm'])->name('faculty.login-form');
        Route::get('faculty/account', [TifrFacultyLoginController::class, 'facultyAccount'])->name('faculty.account');
        Route::post('faculty/submit', [TifrFacultyLoginController::class, 'login'])->name('faculty.submit');
        Route::get('faculty/logout', [TifrFacultyLoginController::class, 'logout'])->name('faculty.logout');

        Route::get('faculty/change-password', [TifrFacultyLoginController::class, 'changePassword'])->name('faculty.change-password');
        Route::post('faculty/update-password', [TifrFacultyLoginController::class, 'updatePassword'])->name('faculty.update-password');

        Route::get('faculty/forgot-password', [TifrFacultyLoginController::class, 'forgotPassword'])->name('faculty.forgot-password');
        // Route::post('faculty/forgot-password-submit', [TifrFacultyLoginController::class, 'forgotPasswordSubmit'])->name('faculty.forgot-password-submit');
        Route::post('faculty/forgot-password-send-email', [TifrFacultyLoginController::class, 'sendResetLinkEmail'])->name('faculty.forgot-password-send-email');
        Route::get('faculty/reset-password/{token}', [TifrFacultyLoginController::class, 'showResetForm'])->name('faculty.reset-password');
        Route::post('faculty/password/reset', [TifrFacultyLoginController::class, 'resetPassword'])->name('faculty.password.update');


        Route::get('faculty-recruitment/verify-email/{token}', [TifrFacultyRegistrationController::class, 'verifyEmail'])
            ->name('faculty-recruitment.verify-email')
            ->middleware('signed');

        Route::get('faculty-recruitment/email-verification', [TifrFacultyRegistrationController::class, 'emailVerificationPage'])->name('faculty-recruitment.email-verification-page');


        // Route::get('/verify-email/{token}', [TifrFacultyRegistrationController::class, 'verifyEmail'])->name('faculty-recruitment.verify-email');

        // Route::get('faculty/password/reset/{token}', [TifrFacultyLoginController::class, 'showResetForm'])->name('faculty.password.reset');
        // Route::post('faculty/password/reset', [TifrFacultyLoginController::class, 'resetPassword'])->name('faculty.password.update');


        // Route::get('/send-welcome-email/{user}', [TifrFacultyRegistrationController::class, 'sendWelcomeEmail'])
        //     ->name('sendWelcomeEmail');

        // http://localhost/laramag_7.4.5/public/faculty-recruitment/create
        // http://localhost/laramag_7.4.5/public/faculty/account
        // http://localhost/laramag_7.4.5/public/send-welcome-email/1
    });
});

Theme::routes();
