<?php

namespace Theme\Tifr\Http\Controllers;

use Botble\Theme\Http\Controllers\PublicController;
use Illuminate\Support\Facades\Mail;
use App\Mail\WelcomeEmail;
use Illuminate\Support\Facades\DB;

class TifrEmailController extends PublicController
{
    // Send registration email to the user
    public function send_email_to_user($userData)
    {
        $email_type = 'registration_confirmation';

        $welcomeEmail = new WelcomeEmail($email_type);

        Mail::to($userData['email'])->send($welcomeEmail->with([
            'name' => $userData['first_name'] . ' ' . $userData['last_name'],
            'email' => $userData['email'],
            'username' => $userData['username'],
            'password' => $userData['plain_password'],
            'email_verification_token_link' => $userData['email_verification_token_link'],
        ]));

        // $this->sendAdminNotificationEmail($userData);
    }


    public function send_email_to_committee_member_and_admin($userData)
    {
        $this->send_email_to_role($userData, 'committee-member');
        $this->send_email_to_role($userData, 'admin');
    }

    public function send_email_to_role($userData, $roleSlug)
    {
        $email_type = 'new_faculty_application';

        $emails = DB::table('users')
            ->join('role_users', 'users.id', '=', 'role_users.user_id')
            ->join('roles', 'role_users.role_id', '=', 'roles.id')
            ->where('roles.slug', $roleSlug)
            ->pluck('users.email');

        $welcomeEmail = new WelcomeEmail($email_type);

        $emailData = [
            'name' => $userData['first_name'] . ' ' . $userData['middle_name'] . ' ' . $userData['last_name'],
            'email' => $userData['email'],
            'phone' => $userData['phone'],
        ];

        foreach ($emails as $email) {
            Mail::to($email)->send($welcomeEmail->with($emailData));
        }
    }

    // Send admin notification email when a candidate applies
    public function sendAdminNotificationEmail($userData)
    {
        $email_type = 'admin_notification';
        $admin_mail = 'koli@imageonline.co.in';

        $adminEmail = new WelcomeEmail($email_type);

        Mail::to($admin_mail)->send($adminEmail->with([
            'name' => $userData['first_name'] . ' ' . $userData['last_name'],
            'email' => $userData['email'],
            // 'address' => $userData['address'],
            'phone' => $userData['phone'],
        ]));
    }

    // Send approval email to the user
    public function sendApprovalEmail()
    {
        // $email_type = 'approval';

        // // Create the email instance
        // $approvalEmail = new WelcomeEmail($email_type);

        // // Send email to the user notifying approval
        // Mail::to($user->email)->send($approvalEmail->with([
        //     'name' => $user->name,
        // ]));

        // // Send email to the chairperson and committee members
        // $this->sendSelectionEmailToCommittee($user);
    }

    // Send email to chairperson and committee members after selection
    private function sendSelectionEmailToCommittee()
    {
        // $selectionEmail = new WelcomeEmail('selection');

        // // Define the committee emails (chairperson and others)
        // $committeeEmails = ['chairperson@example.com', 'committee@example.com']; // Example emails

        // // Send email to each committee member
        // foreach ($committeeEmails as $email) {
        //     Mail::to($email)->send($selectionEmail->with([
        //         'name' => $user->name,
        //     ]));
        // }
    }

    // Send rejection email to the user
    public function sendRejectionEmail()
    {
        // $email_type = 'rejection';

        // // Create the email instance
        // $rejectionEmail = new WelcomeEmail($email_type);

        // // Send email to the user notifying rejection
        // Mail::to($user->email)->send($rejectionEmail->with([
        //     'name' => $user->name,
        // ]));
    }
}
