<?php

namespace Theme\Tifr\Http\Controllers;

use Botble\Theme\Http\Controllers\PublicController;
use App\Notifications\TifrResetPasswordNotification;
// use Illuminate\Support\Facades\Password;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use Theme\Tifr\Models\TifrFacultyLogin;
// use Theme\Tifr\Models\FacultyRecruitment;
use Theme\Tifr\Models\TifrFacultyRegistration;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use App\Mail\TifrPasswordResetMail;
// use App\Mail\TifrEmail;
use Illuminate\Support\Facades\DB;
use Theme;


// class FacultyLoginController extends PublicController
class TifrFacultyLoginController extends PublicController
{

    public function login(Request $request)
    {
        $username = $request->input('username');
        $password = $request->input('password');

        $facultyLogin = TifrFacultyLogin::where('username', $username)->first();

        if ($facultyLogin && Hash::check($password, $facultyLogin->password)) {

            if (is_null($facultyLogin->email_verified_at)) {
                return back()->withInput()->with('error', 'Your email address is not verified. Please check your inbox or spam folder and verify your email. The verification link expires in 24 hours. If you did not receive it, please contact web@tifr.res.in.');
            }

            session([
                'faculty_user_id' => $facultyLogin->id,
                'faculty_username' => $facultyLogin->username
            ]);

            // return redirect()->route('faculty.account')->with('success', 'Login successful');
            return redirect()->route('faculty.account');
        } else {
            return back()->withInput()->with('error', 'Incorrect username or password. Please try again.');
        }
    }

    public function showFacultyLoginForm()
    {
        if (session('faculty_user_id')) {
            return redirect()->route('faculty.account');
        }
        return Theme::uses('tifr')->scope('faculty-login.faculty_login_form')->render();
    }

    public function forgotPassword()
    {
        return Theme::uses('tifr')->scope('faculty-login.faculty_forgot_password')->render();
    }

    // Handle sending reset password link
    public function sendResetLinkEmail(Request $request)
    {
        // Validate the email
        $request->validate([
            'email' => 'required|email|exists:tifr_faculty_logins,email',
        ]);

        $email = $request->input('email');

        // Generate reset token
        $token = Str::random(60);

        // Check if an existing reset token exists
        $existingReset = DB::table('tifr_faculty_password_reset_tokens')->where('email', $email)->first();

        if ($existingReset) {
            // Delete the existing token before inserting a new one
            DB::table('tifr_faculty_password_reset_tokens')->where('email', $email)->delete();
        }

        // Store the token in the tifr_faculty_password_reset_tokens table
        DB::table('tifr_faculty_password_reset_tokens')->insert([
            'email' => $email,
            'token' => $token,
            'created_at' => now(),
        ]);

        // Generate reset link
        $resetLink = route('faculty.reset-password', ['token' => $token, 'email' => $email]);

        // Send reset link to the faculty email
        Mail::to($email)->send(new TifrPasswordResetMail($resetLink));

        // Return response
        return back()->with('status', 'We have e-mailed your password reset link!');
    }

    public function forgotPasswordSubmit111(Request $request)
    {
        // Validate email input
        $validated = $request->validate([
            // 'email' => 'required|email|exists:faculties,email',  // Ensure the email exists in the faculties table
            'email' => 'required|email',  // Ensure the email exists in the faculties table
        ]);

        // Attempt to send a password reset link
        // $response = \Password::sendResetLink(
        //     $validated
        // );

        $response = \Password::sendResetLink(
            $validated,
            function ($user) {
                // Send the custom reset password notification
                $user->notify(new TifrResetPasswordNotification($user->remember_token));
            }
        );

        if ($response == \Password::RESET_LINK_SENT) {
            return back()->with('status', 'We have e-mailed your password reset link!');
        }

        return back()->withErrors(['email' => 'Failed to send reset link. Please try again later.']);
    }

    // public function showResetForm($token)
    // {
    //     // Validate the token (you can add custom validation if needed)
    //     // $resetData = \Password::getRepository()->exists($token); // Optional
    //     $response = \Password::broker()->getRepository()->exists($token);

    //     // If token is invalid, return an error page or redirect
    //     if (!$response) {
    //         return redirect()->route('faculty.login')->withErrors(['token' => 'This password reset link is no longer valid.']);
    //     }

    //     return view('faculty.password.reset', ['token' => $token]);
    // }

    public function showResetForm($token)
    {

        // dd("Token: " . $token);

        // No need for manual token validation, Laravel will handle it automatically
        // return view('faculty.password.reset', ['token' => $token]);

        $email = request('email'); // Retrieve the email parameter from the URL
        return Theme::uses('tifr')->scope('faculty-login.faculty_reset_password', [
            'token' => $token,
            'email' => $email, // Pass it to the view only once
        ])->render();
    }

    public function resetPassword(Request $request)
    {
        // Validate the request
        $request->validate([
            'token' => 'required',
            'email' => 'required|email|exists:tifr_faculty_logins,email',
            'password' => 'required|confirmed|min:6',
        ]);

        // Check if the token is valid
        $resetRecord = DB::table('tifr_faculty_password_reset_tokens')
            ->where('email', $request->email)
            ->where('token', $request->token)
            ->first();

        if (!$resetRecord) {
            // return redirect()->route('login')->withErrors(['token' => 'This password reset token is invalid.']);
            return redirect()->route('faculty.login-form')->with('error', 'This password reset token is invalid.');
        }

        // Update the password in the tifr_faculty_logins table
        TifrFacultyLogin::where('email', $request->email)->update([
            'password' => Hash::make($request->password),
            'plain_password' => $request->password,
        ]);

        // Delete the token after successful password reset
        DB::table('tifr_faculty_password_reset_tokens')->where('email', $request->email)->delete();

        // Redirect with success message
        return redirect()->route('faculty.login-form')->with('status', 'Your password has been reset successfully!');
    }

    public function facultyAccount()
    {
        $facultyId = session('faculty_user_id');

        if (!$facultyId) {
            return redirect()->route('faculty.login-form')->with('error', 'You must be logged in to view your account.');
        }

        $facultyRecruitment = TifrFacultyRegistration::findOrFail($facultyId);

        $facultyLogin = TifrFacultyLogin::where('id', $facultyId)->first();
        if (!$facultyLogin) {
            return redirect()->route('faculty.login-form')->with('error', 'No login record found.');
        }


        // $statusData = DB::table('tifr_faculty_registration_evaluation_statuses')
        //     ->where('faculty_recruitment_application_id', $facultyId)
        //     ->first();

        // $statusData = DB::table('tifr_faculty_registration_evaluations')
        //     ->where('faculty_recruitment_application_id', $facultyId)
        //     ->where('evaluator_role', 'Chairperson')
        //     ->first();

        $statusData = DB::table('tifr_faculty_registration_evaluation_statuses')
            ->where('faculty_recruitment_application_id', $facultyId)
            ->first();

        // Set default status to 'Under Review'
        $status = 'Under Review';
        if ($statusData && $statusData->final_status != '') {
            $status = $statusData->final_status;
        }

        // return view('faculty-login.faculty_account', compact('faculty'));

        // return Theme::uses('tifr')->scope('faculty-login.faculty_account', [
        //     'faculty' => $faculty
        // ])->render();

        $countries = DB::table('tifr_form_countries')->get();
        $salutations = DB::table('tifr_form_salutations')->get();

        $evaluationExists = DB::table('tifr_faculty_registration_evaluations')
            ->where('faculty_recruitment_application_id', $facultyRecruitment->id)
            ->exists();


        return Theme::uses('tifr')->scope('faculty-login.faculty_account', [
            'facultyRecruitment' => $facultyRecruitment,
            'facultyLogin' => $facultyLogin,  // Pass the login information (username, password)
            'status' => $status,
            'countries' => $countries,
            'salutations' => $salutations,
            'evaluationExists' => $evaluationExists,
        ])->render();
    }

    public function logout()
    {
        session()->forget(['faculty_user_id', 'faculty_username']);
        return redirect()->route('faculty.login-form')->with('success', 'Logged out successfully.');
    }

    public function changePassword()
    {
        $facultyId = session('faculty_user_id');

        if (!$facultyId) {
            return redirect()->route('faculty.login-form')->with('error', 'You must be logged in to change your password.');
        }
        return Theme::uses('tifr')->scope('faculty-login.faculty_change_password')->render();
    }

    public function updatePassword(Request $request)
    {

        $facultyId = session('faculty_user_id');

        if (!$facultyId) {
            return redirect()->route('faculty.login-form')->with('error', 'You must be logged in to change your password.');
        }

        $validator = \Validator::make($request->all(), [
            'current_password' => 'required|string',
            'new_password' => 'required|string|min:6|confirmed',
        ]);

        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }

        $facultyLogin = TifrFacultyLogin::find($facultyId);

        if (!$facultyLogin) {
            return redirect()->route('faculty.login-form')->with('error', 'No account found with this ID.');
        }

        if (!Hash::check($request->input('current_password'), $facultyLogin->password)) {
            return back()->withInput()->with('error', 'The current password you entered is incorrect.');
        }

        $facultyLogin->password = Hash::make($request->input('new_password'));
        $facultyLogin->save();

        $facultyLogin->plain_password = $request->input('new_password');
        $facultyLogin->save();

        return redirect()->route('faculty.account')->with('success', 'Your password has been successfully updated.');
    }
}
