<?php

namespace Theme\Tifr\Http\Controllers;

use Botble\Theme\Http\Controllers\PublicController;
use Illuminate\Support\Facades\Hash;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
// use Theme\Tifr\Models\FacultyRecruitment;
use Theme\Tifr\Models\TifrFacultyRegistration;
use Theme\Tifr\Models\TifrFacultyLogin;
use Theme;
// use App\Mail\WelcomeEmail;
// use Illuminate\Support\Facades\Mail;
use Theme\Tifr\Http\Controllers\TifrEmailController;
// use Illuminate\Support\Str;

// class FacultyRecruitmentController extends PublicController
class TifrFacultyRegistrationController extends PublicController
{
    protected $emailController;

    public function __construct(TifrEmailController $emailController)
    {
        $this->emailController = $emailController;
    }

    public function faculty_registration()
    {

        $countries = \DB::table('tifr_form_countries')->get();
        $salutations = \DB::table('tifr_form_salutations')->get();

        // return Theme::uses('tifr')->scope('faculty-recruitment.faculty_registration_form')->render();

        return Theme::uses('tifr')->scope('faculty-recruitment.faculty_registration_form', [
            'countries' => $countries,
            'salutations' => $salutations,
        ])->render();
    }

    public function store(Request $request)
    {

        $data = $request->all();

        $facultyRecruitment = new TifrFacultyRegistration();
        $facultyRecruitment->fill($data)->save();

        // Generate a unique verification token
        // $email_verification_token = sha1($request->email . time());
        $email_verification_token = \Str::random(10);

        // Generate the verification URL with the token
        $email_verification_token_link = \URL::temporarySignedRoute(
            'faculty-recruitment.verify-email',
            now()->addHours(24), // Token expires in 24 hours
            ['token' => $email_verification_token] // Pass the token in the URL
        );

        $facultyLoginData = [
            'first_name' => $request->input('first_name'),
            'middle_name' => $request->input('middle_name'),
            'last_name' => $request->input('last_name'),
            'email' => $request->input('email'),
            'phone' => $request->input('phone'),
            'username' => $request->input('username'),
            'password' => $request->input('password'),
            'plain_password' => $request->input('password'),
            'email_verification_token_link' => $email_verification_token_link,
            'email_verification_token' => $email_verification_token,
            'email_verified_at' => null
        ];

        $facultyLoginData['password'] = Hash::make($facultyLoginData['password']);
        TifrFacultyLogin::create($facultyLoginData);
        $this->emailController->send_email_to_user($facultyLoginData);

        session()->flash('form_submitted', true);
        return redirect()->route('faculty-recruitment.thankyou');
    }

    public function thankyou()
    {
        return Theme::uses('tifr')->scope('faculty-recruitment.thankyou')->render();
    }

    public function update(Request $request)
    {

        $data = $request->all();

        $facultyRecruitment = TifrFacultyRegistration::findOrFail(session('faculty_user_id'));

        $fileFields = [
            'cover_letter',
            'cv',
            'referees_list',
            'research_proposal',
            'publications_list',
            'combined_application'
        ];

        foreach ($fileFields as $field) {

            if ($request->hasFile($field)) {

                $file = $request->file($field);

                $originalFileName = $file->getClientOriginalName();
                $fileName = preg_replace('/[^a-zA-Z0-9\-_\.]/', '_', strtolower(str_replace(' ', '_', $originalFileName)));

                $file->storeAs('tifr_faculty_documents', $fileName, 'public');
                $data[$field] = $fileName;

                if ($facultyRecruitment->$field) {
                    Storage::disk('public')->delete('tifr_faculty_documents/' . $facultyRecruitment->$field);
                }
            }

            if ($request->input('hidden_delete_' . $field) == '1') {
                if ($facultyRecruitment->$field) {
                    Storage::disk('public')->delete('tifr_faculty_documents/' . $facultyRecruitment->$field);
                }
                $data[$field] = null;
            }
        }


        $facultyRecruitment->fill($data)->save();

        $user_data = [
            'first_name' => $facultyRecruitment->first_name,
            'middle_name' => $facultyRecruitment->middle_name,
            'last_name' => $facultyRecruitment->last_name,
            'email' => $facultyRecruitment->email,
            'phone' => $facultyRecruitment->phone,
        ];

        // Send notification email to committee members and admin
        $this->emailController->send_email_to_committee_member_and_admin($user_data);

        return redirect()->route('faculty.account')->with('success', 'Faculty recruitment information updated successfully!');
    }

    public function validateMathCaptchaAndUserUniqueness(Request $request)
    {

        $validator = \Validator::make($request->all(), [
            'captcha_answer' => 'required|math_captcha',
        ]);

        if ($validator->fails()) {
            return response()->json([
                'status' => 'error',
                'message' => 'Incorrect answer, please try again.',
                'errors' => $validator->errors(),
            ], 200);
        }

        $errors = [];
        if (TifrFacultyLogin::where('username', $request->username)->exists()) {
            $errors['username'] = 'Username is already taken.';
        }

        if (TifrFacultyLogin::where('email', $request->email)->exists()) {
            $errors['email'] = 'Email is already registered.';
        }

        if (TifrFacultyLogin::where('phone', $request->phone)->exists()) {
            $errors['phone'] = 'Phone number is already in use.';
        }

        if (!empty($errors)) {
            return response()->json([
                'status' => 'error',
                'errors' => $errors
            ]);
        }

        return response()->json(['status' => 'success']);
    }

    public function verifyEmail(Request $request)
    {

        $token = $request->route('token');

        $user = TifrFacultyLogin::where('email_verification_token', $token)->first();

        if ($user && $request->hasValidSignature()) {

            $user->email_verified_at = now();
            // $user->email_verification_token = null;
            $user->save();

            return redirect()->route('faculty-recruitment.email-verification-page')
                ->with('verification_success', true);
        }

        return redirect()->route('faculty-recruitment.email-verification-page')
            ->with('verification_failed', true);
    }

    public function emailVerificationPage()
    {
        return Theme::uses('tifr')->scope('faculty-recruitment.email_verification')->render();
    }
}
