@php
    $currentUrl = Request::path();

    // Add slash in current URL
    if ($currentUrl[0] !== '/') {
        $currentUrl = '/' . $currentUrl;
    }

    $breadcrumbs = [];

    // Step 1: Find the current page's menu item from the database
$currentNode = DB::table('menu_nodes')->where('url', $currentUrl)->first();

// Step 2: If we found the current node, start building the breadcrumbs
if ($currentNode) {
    // Add the current node to breadcrumbs
    $breadcrumbs[] = ['label' => $currentNode->title, 'url' => url($currentNode->url)];

    // Step 3: Traverse back through the parent nodes until we reach the root
    while ($currentNode->parent_id) {
        $currentNode = DB::table('menu_nodes')
            ->where('id', $currentNode->parent_id)
            ->first();
        if ($currentNode) {
            $breadcrumbs[] = ['label' => $currentNode->title, 'url' => url($currentNode->url)];
        }
    }

    // Step 4: Add "Home" breadcrumb at the beginning
    $breadcrumbs[] = ['label' => 'Home', 'url' => url('/')];

        // Reverse the breadcrumbs array to get the correct order (Home -> Parents -> Current)
        $breadcrumbs = array_reverse($breadcrumbs);
    }

@endphp

@if (!empty($page->slider_shortcode))
    {{ '[simple-slider key="' . $page->slider_shortcode . '"][/simple-slider]' }}
@elseif (!empty($page->image))
    <section class="header-inside section dark-background {{ Request::path() . '-banner' }}"
        style="background:url('../storage/{{ $page->image }}') no-repeat center top; width:100%; background-size:cover;">
    </section>
@endif

<main class="main">
    <?php if(Request::path() !== '/') { ?>
    <section class="about-2 section pb-0" id="starter-section">
        <div class="page-title" data-aos="fade-up" data-aos-delay="100">
            <div class="container d-lg-flex flex-wrap align-items-center">
                <nav class="breadcrumbs">
                    <ol>

                        @foreach ($breadcrumbs as $key => $breadcrumb)
                            <li>
                                @if ($loop->last)
                                    <span class="active">{{ $breadcrumb['label'] }}</span>
                                @elseif ($key === 1)
                                    <span>{{ $breadcrumb['label'] }}</span>
                                @else
                                    <a href="{{ $breadcrumb['url'] }}">{{ $breadcrumb['label'] }}</a>
                                @endif
                            </li>
                        @endforeach

                        {{-- @foreach ($breadcrumbs as $breadcrumb)
                            <li>
                                @if ($loop->last)
                                    <span class="active">{{ $breadcrumb['label'] }}</span>
                                @else
                                    <a href="{{ $breadcrumb['url'] }}">{{ $breadcrumb['label'] }}</a>
                                @endif
                            </li>
                        @endforeach --}}

                        {{-- if you dont want current page in breadcrumb --}}
                        {{-- @foreach ($breadcrumbs as $breadcrumb)
                            @if (!$loop->last)
                                <li>
                                    <a href="{{ $breadcrumb['url'] }}">{{ $breadcrumb['label'] }}</a>
                                </li>
                            @endif
                        @endforeach --}}
                    </ol>
                </nav>
                <div class="inside-heading">{{ $page->name }}</div>
            </div>
        </div>
    </section>
    <?php } ?>

    {!! $page->content !!}
</main>

<script>
    window.addEventListener('scroll', function() {
        const scrollPosition = window.scrollY + window.innerHeight;
        const pageHeight = document.documentElement.scrollHeight;

        // Check if the user is near the bottom, allowing for some margin of error
        const margin = 50; // Increase margin to avoid precision issues

        if (scrollPosition >= pageHeight - margin) {
            document.getElementById('scroll-top').classList.add('btm-scroll');
        } else {
            document.getElementById('scroll-top').classList.remove('btm-scroll');
        }
    });
</script>
